/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.migration.modell.geo;

import java.util.Arrays;
import java.util.Collection;

import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ibv.simbaustelle.migration.modell.ModellObjektFactory;
import de.bsvrz.ibv.simbaustelle.migration.modell.SystemObjekt;
import de.bsvrz.ibv.simbaustelle.migration.modell.SystemObjektTyp;
import de.bsvrz.ibv.simbaustelle.migration.modell.geo.objekte.LinieXYImpl;
import de.bsvrz.ibv.simbaustelle.migration.modell.geo.objekte.PunktXYImpl;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Factory zum Erzeugen von Objekten, aus dem Georeferenzierungs-Modell.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class GeoModellFactory implements ModellObjektFactory {

	/**
	 * Logger für Debug-Ausgaben.
	 */
	private static final Debug LOGGER = Debug.getLogger();

	@Override
	public SystemObjekt getModellobjekt(final SystemObject objekt) {
		if (objekt == null) {
			throw new IllegalArgumentException(
					"Argument darf nicht null sein.");
		}

		SystemObjekt obj = null;
		if (objekt.isOfType(GeoModellTypen.PUNKT_XY.getPid())) {
			obj = new PunktXYImpl(objekt);
		} else if (objekt.isOfType(GeoModellTypen.LINIE_XY.getPid())) {
			obj = new LinieXYImpl(objekt);
		}

		if (obj == null) {
			LOGGER.error("Für das Ohbjekt: " + objekt
					+ " konnte kein Systemobjekt angelegt werden");
		}

		return obj;
	}

	@Override
	public Collection<? extends SystemObjektTyp> getTypen() {
		return Arrays.asList(GeoModellTypen.values());
	}

}
